[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)


# bsb

This project contains the metadata of the [BSB](https://github.com/dbbs-lab/bsb) packages.
